==> org-lsst-sal-atcamera-1.8.0-sources.jar: org/lsst/sal/atcamera/telemetry/WrebPowerTelemetry.java <==
package org.lsst.sal.atcamera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class WrebPowerTelemetry extends CameraTelemetry {
  private final float digital_V;

  private final float digital_I;

  private final float analog_V;

  private final float analog_I;

  private final float clkHigh_V;

  private final float clkHigh_I;

  private final float clkLow_V;

  private final float clkLow_I;

  private final float od_V;

  private final float od_I;

  private final float dphi_V;

  private final float dphi_I;

  private final float heater_V;

  private final float heater_I;

  private final float hvbias_V;

  private final float hvbias_I;

  public WrebPowerTelemetry(float digital_V, float digital_I, float analog_V, float analog_I,
      float clkHigh_V, float clkHigh_I, float clkLow_V, float clkLow_I, float od_V, float od_I,
      float dphi_V, float dphi_I, float heater_V, float heater_I, float hvbias_V, float hvbias_I) {
    this.digital_V = digital_V;
    this.digital_I = digital_I;
    this.analog_V = analog_V;
    this.analog_I = analog_I;
    this.clkHigh_V = clkHigh_V;
    this.clkHigh_I = clkHigh_I;
    this.clkLow_V = clkLow_V;
    this.clkLow_I = clkLow_I;
    this.od_V = od_V;
    this.od_I = od_I;
    this.dphi_V = dphi_V;
    this.dphi_I = dphi_I;
    this.heater_V = heater_V;
    this.heater_I = heater_I;
    this.hvbias_V = hvbias_V;
    this.hvbias_I = hvbias_I;
  }

  public float getDigital_V() {
    return digital_V;
  }

  public float getDigital_I() {
    return digital_I;
  }

  public float getAnalog_V() {
    return analog_V;
  }

  public float getAnalog_I() {
    return analog_I;
  }

  public float getClkHigh_V() {
    return clkHigh_V;
  }

  public float getClkHigh_I() {
    return clkHigh_I;
  }

  public float getClkLow_V() {
    return clkLow_V;
  }

  public float getClkLow_I() {
    return clkLow_I;
  }

  public float getOd_V() {
    return od_V;
  }

  public float getOd_I() {
    return od_I;
  }

  public float getDphi_V() {
    return dphi_V;
  }

  public float getDphi_I() {
    return dphi_I;
  }

  public float getHeater_V() {
    return heater_V;
  }

  public float getHeater_I() {
    return heater_I;
  }

  public float getHvbias_V() {
    return hvbias_V;
  }

  public float getHvbias_I() {
    return hvbias_I;
  }

  @Override
  public String toString() {
    return "WrebPowerTelemetry{" + "digital_V=" + digital_V +", digital_I=" + digital_I +
        ", analog_V=" + analog_V +", analog_I=" + analog_I +", clkHigh_V=" + clkHigh_V +
        ", clkHigh_I=" + clkHigh_I +", clkLow_V=" + clkLow_V +", clkLow_I=" + clkLow_I +
        ", od_V=" + od_V +", od_I=" + od_I +", dphi_V=" + dphi_V +", dphi_I=" + dphi_I +
        ", heater_V=" + heater_V +", heater_I=" + heater_I +", hvbias_V=" + hvbias_V +
        ", hvbias_I=" + hvbias_I +"}";
  }
}

==> org-lsst-sal-atcamera-2.0.4-sources.jar: org/lsst/sal/atcamera/telemetry/WrebPowerTelemetry.java <==
package org.lsst.sal.atcamera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class WrebPowerTelemetry extends CameraTelemetry {
  private final float digital_V;

  private final float digital_I;

  private final float analog_V;

  private final float analog_I;

  private final float clkHigh_V;

  private final float clkHigh_I;

  private final float clkLow_V;

  private final float clkLow_I;

  private final float od_V;

  private final float od_I;

  private final float dphi_V;

  private final float dphi_I;

  private final float hvbias_V;

  private final float hvbias_I;

  private final float fan_V;

  private final float fan_I;

  private final float otm_V;

  private final float otm_I;

  private final float aux_V;

  private final float aux_I;

  public WrebPowerTelemetry(float digital_V, float digital_I, float analog_V, float analog_I,
      float clkHigh_V, float clkHigh_I, float clkLow_V, float clkLow_I, float od_V, float od_I,
      float dphi_V, float dphi_I, float hvbias_V, float hvbias_I, float fan_V, float fan_I,
      float otm_V, float otm_I, float aux_V, float aux_I) {
    this.digital_V = digital_V;
    this.digital_I = digital_I;
    this.analog_V = analog_V;
    this.analog_I = analog_I;
    this.clkHigh_V = clkHigh_V;
    this.clkHigh_I = clkHigh_I;
    this.clkLow_V = clkLow_V;
    this.clkLow_I = clkLow_I;
    this.od_V = od_V;
    this.od_I = od_I;
    this.dphi_V = dphi_V;
    this.dphi_I = dphi_I;
    this.hvbias_V = hvbias_V;
    this.hvbias_I = hvbias_I;
    this.fan_V = fan_V;
    this.fan_I = fan_I;
    this.otm_V = otm_V;
    this.otm_I = otm_I;
    this.aux_V = aux_V;
    this.aux_I = aux_I;
  }

  public float getDigital_V() {
    return digital_V;
  }

  public float getDigital_I() {
    return digital_I;
  }

  public float getAnalog_V() {
    return analog_V;
  }

  public float getAnalog_I() {
    return analog_I;
  }

  public float getClkHigh_V() {
    return clkHigh_V;
  }

  public float getClkHigh_I() {
    return clkHigh_I;
  }

  public float getClkLow_V() {
    return clkLow_V;
  }

  public float getClkLow_I() {
    return clkLow_I;
  }

  public float getOd_V() {
    return od_V;
  }

  public float getOd_I() {
    return od_I;
  }

  public float getDphi_V() {
    return dphi_V;
  }

  public float getDphi_I() {
    return dphi_I;
  }

  public float getHvbias_V() {
    return hvbias_V;
  }

  public float getHvbias_I() {
    return hvbias_I;
  }

  public float getFan_V() {
    return fan_V;
  }

  public float getFan_I() {
    return fan_I;
  }

  public float getOtm_V() {
    return otm_V;
  }

  public float getOtm_I() {
    return otm_I;
  }

  public float getAux_V() {
    return aux_V;
  }

  public float getAux_I() {
    return aux_I;
  }

  @Override
  public String toString() {
    return "WrebPowerTelemetry{" + "digital_V=" + digital_V +", digital_I=" + digital_I +
        ", analog_V=" + analog_V +", analog_I=" + analog_I +", clkHigh_V=" + clkHigh_V +
        ", clkHigh_I=" + clkHigh_I +", clkLow_V=" + clkLow_V +", clkLow_I=" + clkLow_I +
        ", od_V=" + od_V +", od_I=" + od_I +", dphi_V=" + dphi_V +", dphi_I=" + dphi_I +
        ", hvbias_V=" + hvbias_V +", hvbias_I=" + hvbias_I +", fan_V=" + fan_V +", fan_I=" + fan_I +
        ", otm_V=" + otm_V +", otm_I=" + otm_I +", aux_V=" + aux_V +", aux_I=" + aux_I +"}";
  }
}
